@@ -179,6 +179,10 @@ class TikTokApi:
                 "accept": "application/json, text/plain, */*",
                 "accept-encoding": "gzip, deflate, br",
                 "accept-language": "en-US,en;q=0.9",
+                "cache-control": "no-cache",
+                "dnt": "1",
+                "origin": referrer,
+                "pragma": 'no-cache',
                 "referer": referrer,
                 "sec-fetch-dest": "empty",
                 "sec-fetch-mode": "cors",
